#
# spec file for package mercurial-extension-hg-evolve
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mercurial-extension-hg-evolve
Version:        11.1.2
Release:        1.1
Summary:        Flexible evolution of Mercurial history
License:        GPL-2.0-or-later
Group:          Development/Tools/Version Control
URL:            https://www.mercurial-scm.org/doc/evolution/
Source0:        https://files.pythonhosted.org/packages/source/h/hg-evolve/hg-evolve-%{version}.tar.gz
Source90:       tests.blacklist
BuildRequires:  fdupes
BuildRequires:  mercurial
BuildRequires:  mercurial-tests
BuildRequires:  python-rpm-macros
BuildRequires:  python3
BuildRequires:  python3-flake8
BuildRequires:  python3-pyflakes
BuildRequires:  python3-setuptools
BuildRequires:  unzip
Requires:       mercurial
BuildArch:      noarch

%description
Flexible evolution of Mercurial history.

%prep
%setup -q -n hg-evolve-%{version}

%build
%python3_build

%install
%python3_install

# Delete hgext3rd/__init__.py and its cached version because it is already delivered by mercurial.
rm %{buildroot}%{python3_sitelib}/hgext3rd/__init__.py
rm %{buildroot}%{python3_sitelib}/hgext3rd/__pycache__/__init__*.pyc

%fdupes %{buildroot}%{python3_sitelib}

%check
cd tests
python3 %{_datadir}/mercurial/tests/run-tests.py --with-hg=%{_bindir}/hg --blacklist=%{SOURCE90}

%files
%doc CHANGELOG README.rst
%license COPYING
%{python3_sitelib}/*

%changelog
* Fri Mar 22 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 11.1.2.
  * compatibility with Mercurial 6.7
  * evolve: use functions from topic extension to set current topic and tns
  topic (1.1.2)
  * compatibility with Mercurial 6.7
  * topic: handle commitstatus() with opts=None for hg <= 6.5 too
- Changelog from version 11.1.1.
  * compatibility with Mercurial 6.6
  * evolve: fix typo in "mercurial" and let hasmemmergestate be True sometimes
  * uncommit: set uncommit_source extra consistently in interactive mode
  topic (1.1.1)
  * compatibility with Mercurial 6.6
  * topic: properly decode topic and topic namespace after reading from disk
  * topic: wrap makebundlerepository() to wrap bundlerepository class (issue6856)
  * topic: internal config option to fix hg pick behavior (issue6406)
  * topic: use the appropriate functions to change topic and topic namespace on working directory update and don't write empty/default values to disk
  * topic namespaces: check that user-provided topic namespace names are human-readable like topics
  * topic namespaces: add tns_heads method to wirepeer directly instead of using a subclass
  * topic namespaces: remove .hg/topic-namespace file if it has the default value ("none")
* Tue Oct 24 2023 Andrei Dziahel <develop7@develop7.info>
- Update to version 11.1.0
  * drop compatibility with Mercurial 4.8
  * remove deprecated evolve.serveronly extension, evolve extension is
    recommended for all users, clients and servers
  * evolve: don't warn about topics while resolving public
    content-divergence
  * evolve, pullbundle: drop compatibility with Mercurial 4.8
  * topic (1.1.0)
  * remove deprecated serverminitopic extension, topic extension
    is recommended for all users, clients and servers
  * pick: update commit message hashes like other rewrite commands
  * topic namespaces: add `experimental.tns-allow-rewrite` config option to
    check topic namespace before rewriting changesets (known limitations: does
    not prevent rebase and histedit from editing changesets outside of
    configured topic namespaces on Mercurial 5.2 and older)
  * topic namespaces: add `experimental.tns-default-pull-namespaces` config
    option to pull only certain changesets by default
  * topic namespaces: teach `hg import` and `hg export` to handle topic
    namespaces
  * topic namespaces: invalidate topic namespace cache in
    repo.invalidatecaches()
  * topic: only set topic on workingcommitctx if it doesn't already have one,
    making `hg import` always prioritize patch metadata
  * topic: properly process revbranchcache before sending it to peers
    (issue6841)
* Mon Aug  7 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 11.0.2.
  * compatibility with Mercurial 6.5
  * packaging: explicitly use python3 for running tests in debian/rules
* Mon Mar 27 2023 Andrei Dziahel <develop7@develop7.info>
- Update to version 11.0.1
  * compatibility with Mercurial 6.4
* Tue Mar 14 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 11.0.0.
  Changelog: https://foss.heptapod.net/mercurial/evolve/-/blob/11.0.0/CHANGELOG
  * deprecate evolve.serveronly extension, evolve extension is recommended for
    all users, clients and servers
  * fixup: support `hg abort`
  * evolve, pick, fixup: support `hg continue`
  * evolve: stop preserving all of {extras} for uninterrupted evolve operations
  * evolve: don't embed graft data when completing interrupted evolve
    operations
  * prune: pruning (without any successors) an already obsolete revision will
    no longer give a false warning about divergence
  * evolve: use detailed exit codes for most commands (enabled with
    `ui.detailed-exit-code=yes`)
* Thu Dec 22 2022 Andrei Dziahel <develop7@develop7.info>
- Update to version 10.5.3
  Changelog: https://foss.heptapod.net/mercurial/evolve/-/blob/10.5.3/CHANGELOG
- Temporarily blacklist test-cmdserver.t
* Tue Jul 19 2022 Andrei Dziahel <develop7@develop7.info>
- Update to version 10.5.2
  Changelog: https://foss.heptapod.net/mercurial/evolve/-/blob/10.5.2/CHANGELOG
* Fri Jun 17 2022 Lukas Müller <expeehaa@outlook.com>
- Blacklist test that fails due to distutils deprecation warning.
* Mon May  2 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 10.5.1.
  Changelog: https://foss.heptapod.net/mercurial/evolve/-/blob/10.5.1/CHANGELOG
* Mon Mar  7 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 10.5.0.
- Changelog: https://foss.heptapod.net/mercurial/evolve/-/blob/10.5.0/CHANGELOG
* Wed Jan 19 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 10.4.1.
- Changelog: https://foss.heptapod.net/mercurial/evolve/-/blob/10.4.1/CHANGELOG
* Wed Nov 10 2021 Lukas Müller <expeehaa@outlook.com>
- Update to version 10.4.0.
- Changelog: https://foss.heptapod.net/mercurial/evolve/-/blob/10.4.0/CHANGELOG
* Fri Sep 24 2021 Lukas Müller <expeehaa@outlook.com>
- Add a test blacklist and run tests on all distributions.
* Mon Sep 20 2021 Lukas Müller <expeehaa@outlook.com>
- Create package mercurial-extension-hg-evolve with hg-evolve version 10.3.3.
